@@ -1,12 +1,15 @@
 /* Declarations of IRC message structures, variables, and functions.
  *
- * IRC Services is copyright (c) 1996-2005 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
+#ifndef MESSAGES_H
+#define MESSAGES_H
+
 /*************************************************************************/
 
 /* Type of a message function: */
@@ -24,3 +27,15 @@ extern int messages_init(int ac, char **av);
 extern void messages_cleanup(void);
 
 /*************************************************************************/
+
+#endif  /* MESSAGES_H */
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
