@@ -1866,6 +1866,7 @@ static void *th_mlock(char *tag, char *attr, char *attrval)
     char tag2[256];
     static ModeLock mlock;
 
+    memset(&mlock, 0, sizeof(mlock));
     while ((result = parse_tag(tag, tag2, NULL, NULL)) != PARSETAG_END) {
         if (result == NULL) {
             return NULL;
@@ -2371,7 +2372,7 @@ static int read_data(int flags)
                       " database, skipping", md->mask, s);
                 my_free_maskdata(md);
             } else {
-                LIST_INSERT(md, md_list[md->type]);
+                LIST_APPEND(md, md_list[md->type]);
             }
 
         } else if (stricmp(tag, "serverstats") == 0) {
@@ -2494,9 +2495,10 @@ static void merge_data(int flags)
 
     for (i = 0; i < 256; i++) {
         LIST_FOREACH_SAFE (md, md_list[i], md2) {
+            MaskData *newmd;  // Because the pointer gets changed
             LIST_REMOVE(md, md_list[i]);
-            add_maskdata(i, md);
-            error("Mask data %d/%s imported", i, md->mask);
+            newmd = add_maskdata(i, md);
+            error("Mask data %d/%s imported", i, newmd->mask);
         }
     }
 
