@@ -4,10 +4,10 @@
  * It is maintained by Chris Plant
  *     E-mail: <chris@monkeyircd.org>
  *
- * IRC Services is copyright (c) 1996-2007 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
@@ -19,12 +19,11 @@
 #include "modules/operserv/operserv.h"
 #include "modules/nickserv/nickserv.h"
 
-#include "sjoin.h"
-#include "halfop.h"
+#include "sjoin.c"
+#include "halfop.c"
 
 /*************************************************************************/
 
-static Module *module;
 static Module *module_operserv;
 
 static char *NetworkDomain = NULL;
@@ -52,12 +51,12 @@ struct modedata_init {
 
 static const struct modedata_init new_usermodes[] = {
     {'r', {0x00000020,0,0,0,MI_REGISTERED}},
-				/* Registered nick */
+                                /* Registered nick */
 };
 
 static const struct modedata_init new_chanmodes[] = {
     {'r', {0x00000200,0,0,0,MI_REGISTERED}},
-				/* Set for all registered channels */
+                                /* Set for all registered channels */
 };
 
 static const struct modedata_init new_chanusermodes[] = {
@@ -69,11 +68,11 @@ static void init_modes(void)
     int i;
 
     for (i = 0; i < lenof(new_usermodes); i++)
-	usermodes[new_usermodes[i].mode] = new_usermodes[i].data;
+        usermodes[new_usermodes[i].mode] = new_usermodes[i].data;
     for (i = 0; i < lenof(new_chanmodes); i++)
-	chanmodes[new_chanmodes[i].mode] = new_chanmodes[i].data;
+        chanmodes[new_chanmodes[i].mode] = new_chanmodes[i].data;
     for (i = 0; i < lenof(new_chanusermodes); i++)
-	chanusermodes[new_chanusermodes[i].mode] = new_chanusermodes[i].data;
+        chanusermodes[new_chanusermodes[i].mode] = new_chanusermodes[i].data;
 
     mode_setup();
 };
@@ -84,43 +83,36 @@ static void init_modes(void)
 
 static void m_nick(char *source, int ac, char **av)
 {
-    char *newmodes;
+    char *newav[10];
 
     if (*source) {
-	/* Old user changing nicks. */
-	if (ac != 2) {
-	    if (debug)
-		module_log("debug: NICK message: wrong number of parameters"
-			   " (%d) for source `%s'", ac, source);
-	} else {
-	    do_nick(source, ac, av);
-	}
-	return;
+        /* Old user changing nicks. */
+        if (ac != 2) {
+            module_log_debug(1, "NICK message: wrong number of parameters"
+                             " (%d) for source `%s'", ac, source);
+        } else {
+            do_nick(source, ac, av);
+        }
+        return;
     }
 
     /* New user. */
     if (ac != 9) {
-	if (debug)
-	    module_log("debug: NICK message: wrong number of parameters (%d)"
-		       " for new user", ac);
-	return;
-    }
-
-    /* With Bahamut, new users get modes in the NICK message.  Save the
-     * modes and strip the parameter out. */
-    newmodes = av[3];
-    memmove(&av[3], &av[4], sizeof(char *) * (ac-4));
-    ac--;
-	
-    /* Rearrange for do_nick */
-    av[6] = av[8];
-    av[7] = NULL; /* Safety  */
-    av[8] = NULL;
-
-    if (do_nick(source, ac, av)) {
-	av[1] = newmodes;
-	do_umode(av[0], 2, av);
+        module_log_debug(1, "NICK message: wrong number of parameters (%d)"
+                         " for new user", ac);
+        return;
     }
+    newav[0] = av[0];   /* Nick */
+    newav[1] = av[1];   /* Hop count */
+    newav[2] = av[2];   /* Timestamp */
+    newav[3] = av[4];   /* Username */
+    newav[4] = av[5];   /* Hostname */
+    newav[5] = av[6];   /* Server */
+    newav[6] = av[7];   /* Real name */
+    newav[7] = NULL;    /* Services stamp */
+    newav[8] = NULL;    /* IP address */
+    newav[9] = av[3];   /* Modes */
+    do_nick(source, 10, newav);
 }
 
 /*************************************************************************/
@@ -130,8 +122,8 @@ static void m_capab(char *source, int ac, char **av)
     int i;
 
     for (i = 0; i < ac; i++) {
-	if (stricmp(av[i], "TS4") == 0)
-	    protocol_features |= PF_NOQUIT;
+        if (stricmp(av[i], "TS4") == 0)
+            protocol_features |= PF_NOQUIT;
     }
 }
 
@@ -140,9 +132,8 @@ static void m_capab(char *source, int ac, char **av)
 static void m_sjoin(char *source, int ac, char **av)
 {
     if (ac == 3 || ac < 2) {
-	if (debug)
-	    module_log("debug: SJOIN: expected 2 or >=4 params, got %d", ac);
-	return;
+        module_log_debug(1, "SJOIN: expected 2 or >=4 params, got %d", ac);
+        return;
     }
     do_sjoin(source, ac, av);
 }
@@ -154,28 +145,28 @@ static void m_sjoin(char *source, int ac, char **av)
 static void m_svsmode(char *source, int ac, char **av)
 {
     if (*av[0] == '#') {
-	if (ac >= 3 && strcmp(av[1],"-b") == 0) {
-	    Channel *c = get_channel(av[0]);
-	    User *u = get_user(av[2]);
-	    if (c && u)
-		clear_channel(c, CLEAR_BANS, u);
-	} else {
-	    module_log("Invalid SVSMODE from %s for channel %s: %s",
-		       source, av[0], merge_args(ac-1,av+1));
-	}
+        if (ac >= 3 && strcmp(av[1],"-b") == 0) {
+            Channel *c = get_channel(av[0]);
+            User *u = get_user(av[2]);
+            if (c && u)
+                clear_channel(c, CLEAR_BANS, u);
+        } else {
+            module_log("Invalid SVSMODE from %s for channel %s: %s",
+                       source, av[0], merge_args(ac-1,av+1));
+        }
     } else if (*av[0] == '&') {
-	module_log("SVSMODE from %s for invalid target (channel %s): %s",
-		   source, av[0], merge_args(ac-1,av+1));
+        module_log("SVSMODE from %s for invalid target (channel %s): %s",
+                   source, av[0], merge_args(ac-1,av+1));
     } else {
-	if (ac < 2)
-	    return;
-	if (ac >= 3 && (*av[2] == '+' || *av[2] == '-')) {
-	    /* Move the timestamp to the end */
-	    char *ts = av[1];
-	    memmove(av+1, av+2, sizeof(char *) * (ac-2));
-	    av[ac-1] = ts;
-	}
-	do_umode(source, ac, av);
+        if (ac < 2)
+            return;
+        if (ac >= 3 && (*av[2] == '+' || *av[2] == '-')) {
+            /* Move the timestamp to the end */
+            char *ts = av[1];
+            memmove(av+1, av+2, sizeof(char *) * (ac-2));
+            av[ac-1] = ts;
+        }
+        do_umode(source, ac, av);
     }
 }
 
@@ -198,13 +189,13 @@ static Message monkeyircd_messages[] = {
 /* Send a NICK command for a new user. */
 
 static void do_send_nick(const char *nick, const char *user, const char *host,
-			 const char *server, const char *name,
-			 const char *modes)
+                         const char *server, const char *name,
+                         const char *modes)
 {
     /* NICK <nick> <hops> <TS> <umode> <user> <host> <server> <svsid>
      *      :<ircname> */
     send_cmd(NULL, "NICK %s 1 %ld +%s %s %s %s 0 0 :%s", nick,
-	     (long)time(NULL), modes, user, host, server, name);
+             (long)time(NULL), modes, user, host, server, name);
 }
 
 /*************************************************************************/
@@ -277,14 +268,14 @@ static void do_notice_all(const char *source, const char *fmt, ...)
     vsnprintf(msgbuf, sizeof(msgbuf), fmt, args);
     va_end(args);
     if (NetworkDomain) {
-	send_cmd(source, "NOTICE $*.%s :%s", NetworkDomain, msgbuf);
+        send_cmd(source, "NOTICE $*.%s :%s", NetworkDomain, msgbuf);
     } else {
-	/* Go through all common top-level domains.  If you have others,
-	 * add them here. */
-	send_cmd(source, "NOTICE $*.com :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.net :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.org :%s", msgbuf);
-	send_cmd(source, "NOTICE $*.edu :%s", msgbuf);
+        /* Go through all common top-level domains.  If you have others,
+         * add them here. */
+        send_cmd(source, "NOTICE $*.com :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.net :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.org :%s", msgbuf);
+        send_cmd(source, "NOTICE $*.edu :%s", msgbuf);
     }
 }
 
@@ -317,41 +308,41 @@ static int do_user_mode(User *user, int modechar, int add, char **av)
 {
     switch (modechar) {
       case 'd':
-	module_log("MODE tried to change services stamp for %s", user->nick);
-	send_cmd(ServerName, "SVSMODE %s +d %u", user->nick,
-		 user->servicestamp);
-	return 0;
+        module_log("MODE tried to change services stamp for %s", user->nick);
+        send_cmd(ServerName, "SVSMODE %s +d %u", user->nick,
+                 user->servicestamp);
+        return 0;
 
       case 'o':
-	if (add) {
-	    user->mode |= UMODE_o;
-	    if (add && user_identified(user) && is_services_admin(user))
-		send_cmd(ServerName, "SVSMODE %s +a", user->nick);
-	    user->mode &= ~UMODE_o;
-	}
-	return 0;
+        if (add) {
+            user->mode |= UMODE_o;
+            if (add && user_identified(user) && is_services_admin(user))
+                send_cmd(ServerName, "SVSMODE %s +a", user->nick);
+            user->mode &= ~UMODE_o;
+        }
+        return 0;
 
       case 'r':
-	if (user_identified(user)) {
-	    if (!add)
-		send_cmd(ServerName, "SVSMODE %s +r", user->nick);
-	} else {
-	    if (add)
-		send_cmd(ServerName, "SVSMODE %s -r", user->nick);
-	}
-	return 1;
+        if (user_identified(user)) {
+            if (!add)
+                send_cmd(ServerName, "SVSMODE %s +r", user->nick);
+        } else {
+            if (add)
+                send_cmd(ServerName, "SVSMODE %s -r", user->nick);
+        }
+        return 1;
 
       case 'a':
-	if (is_oper(user)) {
-	    if (is_services_admin(user)) {
-		if (!add)
-		    send_cmd(ServerName, "SVSMODE %s +a", user->nick);
-	    } else {
-		if (add)
-		    send_cmd(ServerName, "SVSMODE %s -a", user->nick);
-	    }
-	    return 1;
-	}
+        if (is_oper(user)) {
+            if (is_services_admin(user)) {
+                if (!add)
+                    send_cmd(ServerName, "SVSMODE %s +a", user->nick);
+            } else {
+                if (add)
+                    send_cmd(ServerName, "SVSMODE %s -a", user->nick);
+            }
+            return 1;
+        }
     }
     return 0;
 }
@@ -361,33 +352,33 @@ static int do_user_mode(User *user, int modechar, int add, char **av)
 static int do_nick_identified(User *u, int old_status)
 {
     if (is_oper(u) && is_services_admin(u))
-	send_cmd(ServerName, "SVSMODE %s +a", u->nick);
+        send_cmd(ServerName, "SVSMODE %s +a", u->nick);
     return 0;
 }
 
 /*************************************************************************/
 
 static int do_set_topic(const char *source, Channel *c, const char *topic,
-			const char *setter, time_t t)
+                        const char *setter, time_t t)
 {
     if (setter)
-	return 0;
+        return 0;
     c->topic_time = t;
     send_cmd(source, "TOPIC %s %s %ld :%s", c->name, c->topic_setter,
-	     (long)c->topic_time, c->topic ? c->topic : "");
+             (long)c->topic_time, c->topic ? c->topic : "");
     return 1;
 }
 
 /*************************************************************************/
 
 static int do_send_akill(const char *username, const char *host,
-			 time_t expires, const char *who, const char *reason)
+                         time_t expires, const char *who, const char *reason)
 {
     time_t now = time(NULL);
 
     send_cmd(ServerName, "AKILL %s %s %ld %s %ld :%s", host, username,
-	     (long)((expires && expires > now) ? expires - now : 0),
-	     who ? who : "<unknown>", (long)now, reason);
+             (long)((expires && expires > now) ? expires - now : 0),
+             who ? who : "<unknown>", (long)now, reason);
     return 1;
 }
 
@@ -402,21 +393,21 @@ static int do_cancel_akill(const char *username, const char *host)
 /*************************************************************************/
 
 static int do_send_sgline(const char *mask, time_t expires, const char *who,
-			  const char *reason)
+                          const char *reason)
 {
     send_cmd(ServerName, "SGLINE %d :%s:%s", (int)strlen(mask), mask, reason);
     return 1;
 }
 
 static int do_send_sqline(const char *mask, time_t expires, const char *who,
-			  const char *reason)
+                          const char *reason)
 {
     send_cmd(ServerName, "SQLINE %s :%s", mask, reason);
     return 1;
 }
 
 static int do_send_szline(const char *mask, time_t expires, const char *who,
-			  const char *reason)
+                          const char *reason)
 {
     send_cmd(ServerName, "SZLINE %s :%s", mask, reason);
     return 1;
@@ -446,8 +437,6 @@ static int do_cancel_szline(const char *mask)
 /***************************** Module stuff ******************************/
 /*************************************************************************/
 
-const int32 module_version = MODULE_VERSION_CODE;
-
 ConfigDirective module_config[] = {
     { "NetworkDomain", { { CD_STRING, 0, &NetworkDomain } } },
     SJOIN_CONFIG,
@@ -459,33 +448,33 @@ ConfigDirective module_config[] = {
 static int do_load_module(Module *mod, const char *modname)
 {
     if (strcmp(modname, "operserv/main") == 0) {
-	module_operserv = mod;
-	p_is_services_admin = get_module_symbol(mod, "is_services_admin");
-	if (!p_is_services_admin) {
-	    module_log("warning: unable to look up symbol `is_services_admin'"
-		       " in module `operserv/main'");
-	}
+        module_operserv = mod;
+        p_is_services_admin = get_module_symbol(mod, "is_services_admin");
+        if (!p_is_services_admin) {
+            module_log("warning: unable to look up symbol `is_services_admin'"
+                       " in module `operserv/main'");
+        }
     } else if (strcmp(modname, "operserv/akill") == 0) {
-	if (!add_callback(mod, "send_akill", do_send_akill))
-	    module_log("Unable to add send_akill callback");
-	if (!add_callback(mod, "cancel_akill", do_cancel_akill))
-	    module_log("Unable to add cancel_akill callback");
+        if (!add_callback(mod, "send_akill", do_send_akill))
+            module_log("Unable to add send_akill callback");
+        if (!add_callback(mod, "cancel_akill", do_cancel_akill))
+            module_log("Unable to add cancel_akill callback");
     } else if (strcmp(modname, "operserv/sline") == 0) {
-	if (!add_callback(mod, "send_sgline", do_send_sgline))
-	    module_log("Unable to add send_sgline callback");
-	if (!add_callback(mod, "send_sqline", do_send_sqline))
-	    module_log("Unable to add send_sqline callback");
-	if (!add_callback(mod, "send_szline", do_send_szline))
-	    module_log("Unable to add send_szline callback");
-	if (!add_callback(mod, "cancel_sgline", do_cancel_sgline))
-	    module_log("Unable to add cancel_sgline callback");
-	if (!add_callback(mod, "cancel_sqline", do_cancel_sqline))
-	    module_log("Unable to add cancel_sqline callback");
-	if (!add_callback(mod, "cancel_szline", do_cancel_szline))
-	    module_log("Unable to add cancel_szline callback");
+        if (!add_callback(mod, "send_sgline", do_send_sgline))
+            module_log("Unable to add send_sgline callback");
+        if (!add_callback(mod, "send_sqline", do_send_sqline))
+            module_log("Unable to add send_sqline callback");
+        if (!add_callback(mod, "send_szline", do_send_szline))
+            module_log("Unable to add send_szline callback");
+        if (!add_callback(mod, "cancel_sgline", do_cancel_sgline))
+            module_log("Unable to add cancel_sgline callback");
+        if (!add_callback(mod, "cancel_sqline", do_cancel_sqline))
+            module_log("Unable to add cancel_sqline callback");
+        if (!add_callback(mod, "cancel_szline", do_cancel_szline))
+            module_log("Unable to add cancel_szline callback");
     } else if (strcmp(modname, "nickserv/main") == 0) {
-	if (!add_callback(mod, "identified", do_nick_identified))
-	    module_log("Unable to add NickServ identified callback");
+        if (!add_callback(mod, "identified", do_nick_identified))
+            module_log("Unable to add NickServ identified callback");
     }
     return 0;
 }
@@ -495,46 +484,45 @@ static int do_load_module(Module *mod, const char *modname)
 static int do_unload_module(Module *mod)
 {
     if (mod == module_operserv) {
-	module_operserv = NULL;
-	p_is_services_admin = NULL;
+        module_operserv = NULL;
+        p_is_services_admin = NULL;
     }
     return 0;
 }
 
 /*************************************************************************/
 
-int init_module(Module *module_)
+int init_module(void)
 {
     unsigned char c;
 
-    module = module_;
 
-    protocol_name     = "Monkeyircd";
-    protocol_version  = "1.0";
+    protocol_name     = "Chunky Monkey IRCD";
+    protocol_version  = "1.0+";
     protocol_features = 0;
     protocol_nickmax  = 30;
 
     if (!register_messages(monkeyircd_messages)) {
-	module_log("Unable to register messages");
-	exit_module(1);
-	return 0;
+        module_log("Unable to register messages");
+        exit_module(1);
+        return 0;
     }
 
     if (!add_callback(NULL, "load module", do_load_module)
      || !add_callback(NULL, "unload module", do_unload_module)
      || !add_callback(NULL, "user servicestamp change",
-		      do_user_servicestamp_change)
+                      do_user_servicestamp_change)
      || !add_callback(NULL, "user MODE", do_user_mode)
      || !add_callback(NULL, "set topic", do_set_topic)
     ) {
-	module_log("Unable to add callbacks");
-	exit_module(1);
-	return 0;
+        module_log("Unable to add callbacks");
+        exit_module(1);
+        return 0;
     }
 
-    if (!init_halfop(module) || !init_sjoin(module) ) {
-	exit_module(1);
-	return 0;
+    if (!init_halfop() || !init_sjoin()) {
+        exit_module(1);
+        return 0;
     }
 
     init_modes();
@@ -542,10 +530,9 @@ int init_module(Module *module_)
     irc_lowertable['['] = '[';
     irc_lowertable['\\'] = '\\';
     irc_lowertable[']'] = ']';
-    for (c = 'A'; c <= '}'; c++)
-	valid_nick_table[c] = 3;
+    valid_nick_table['}'] = 0;  /* off-by-one bug in 1.0.4 */
     for (c = 0; c < 32; c++)
-	valid_chan_table[c] = 0;
+        valid_chan_table[c] = 0;
     valid_chan_table[160] = 0;
 
     send_nick          = do_send_nick;
@@ -558,8 +545,9 @@ int init_module(Module *module_)
     send_channel_cmd   = do_send_channel_cmd;
     pseudoclient_modes = "";
     enforcer_modes     = "";
+    pseudoclient_oper  = 0;
 
-    setstring(OPER_BOUNCY_MODES, OPER_BOUNCY_MODES_U_LINE);
+    mapstring(OPER_BOUNCY_MODES, OPER_BOUNCY_MODES_U_LINE);
 
     return 1;
 }
@@ -569,8 +557,8 @@ int init_module(Module *module_)
 int exit_module(int shutdown)
 {
     if (!shutdown) {
-	/* Do not allow removal */
-	return 0;
+        /* Do not allow removal */
+        return 0;
     }
 
     exit_sjoin();
@@ -578,7 +566,7 @@ int exit_module(int shutdown)
     remove_callback(NULL, "set topic", do_set_topic);
     remove_callback(NULL, "user MODE", do_user_mode);
     remove_callback(NULL, "user servicestamp change",
-		    do_user_servicestamp_change);
+                    do_user_servicestamp_change);
     remove_callback(NULL, "unload module", do_unload_module);
     remove_callback(NULL, "load module", do_load_module);
     unregister_messages(monkeyircd_messages);
@@ -586,3 +574,13 @@ int exit_module(int shutdown)
 }
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
