@@ -1,44 +1,40 @@
 /* Code for servers supporting the ircd.dal SVSNICK command.
  *
- * IRC Services is copyright (c) 1996-2005 Andrew Church.
+ * IRC Services is copyright (c) 1996-2009 Andrew Church.
  *     E-mail: <achurch@achurch.org>
  * Parts written by Andrew Kempe and others.
- * This program is free but copyrighted software; see the file COPYING for
+ * This program is free but copyrighted software; see the file GPL.txt for
  * details.
  */
 
 #include "services.h"
-#include "language.h"
 #include "modules.h"
-#include "modules/nickserv/nickserv.h"
 
 #include "svsnick.h"
 
-/*************************************************************************/
-
-static Module *module;
+/* Command name for SVSNICK */
+static const char *cmd_SVSNICK = "SVSNICK";
 
 /*************************************************************************/
 /*************************************************************************/
 
-/* Send a SVSNICK to change a client's nickname. */
+/* Send a command to change the nickname of a user on another server. */
 
-static void do_send_nickchange_remote(const char *nick, const char *newnick)
+static void svsnick_send_nickchange_remote(const char *nick,
+                                           const char *newnick)
 {
-    send_cmd(ServerName, "SVSNICK %s %s :%ld", nick, newnick,
-	     (long)time(NULL));
+    send_cmd(ServerName, "%s %s %s :%ld", cmd_SVSNICK, nick, newnick,
+             (long)time(NULL));
 }
 
 /*************************************************************************/
 /*************************************************************************/
 
-int init_svsnick(Module *module_)
+int init_svsnick(const char *cmdname)
 {
-    module = module_;
-
-    send_nickchange_remote = do_send_nickchange_remote;
+    cmd_SVSNICK = cmdname;
+    send_nickchange_remote = svsnick_send_nickchange_remote;
     protocol_features |= PF_CHANGENICK;
-
     return 1;
 }
 
@@ -51,3 +47,13 @@ void exit_svsnick(void)
 }
 
 /*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
